#!/usr/bin/env python2.5
#
import py_compile
import os

py_compile.compile("/opt/barriosquare/barriosq.py")
py_compile.compile("/opt/barriosquare/barriodata.py")
py_compile.compile("/opt/barriosquare/barriotime.py")
py_compile.compile("/opt/barriosquare/bootstrap.py")
py_compile.compile("/opt/barriosquare/barrioConfig.py")
py_compile.compile("/opt/barriosquare/barrioStyles.py")
py_compile.compile("/opt/barriosquare/oauthlib.py")
py_compile.compile("/opt/barriosquare/oauthclient.py")
py_compile.compile("/opt/barriosquare/get-location.py")
py_compile.compile("/opt/barriosquare/foursquare.py")
